@@ -2,6 +2,7 @@ from copy import deepcopy
 import pandas as pd
 import numpy as np
 
+
 def get_group(pid, groups):
     """
     This functions get the group of the corresponding id of the page.
@@ -20,15 +21,16 @@ def get_group(pid, groups):
     str 
     """
 
-    group_out='no_group'
+    group_out = 'no_group'
     try:
         for group in groups:
             if pid in groups[group]:
-                group_out=group
+                group_out = group
     except Exception:
         pass
     return group_out
 
+
 def discretize(df, from_column, to_column=None, n_groups=10):
     """
     This functions discretizes de column 'from_column' into the column 'to_column' in the 
@@ -47,8 +49,9 @@ def discretize(df, from_column, to_column=None, n_groups=10):
     """
     if from_column in df.keys():
         if to_column:
-            df[to_column] = pd.cut(df[from_column], n_groups, labels=range(1,n_groups+1))
+            df[to_column] = pd.cut(df[from_column], n_groups, labels=range(1, n_groups + 1))
         else:
-            df[f'disc_{from_column}'] = pd.cut(df[from_column], n_groups, labels=range(1,n_groups+1))
+            df[f'disc_{from_column}'] = pd.cut(
+                df[from_column], n_groups, labels=range(1, n_groups + 1))
     else:
         raise RuntimeError(f'{from_column} is not a column available of input DataFrame.')
