@@ -15,12 +15,12 @@ path_tokenizer = path_models + 'tokenizer'
 
 ERR_SYS = "\nSystem error: "
 # bertnlp_model = AutoModelForSequenceClassification.from_pretrained(path_sentiment)
-bertnlp_model = None
 # bert_tokenizer = BertTokenizerFast.from_pretrained(path_tokenizer)
-bert_tokenizer = None
-spacy.prefer_gpu()
 # nlp_model = spacy.load('es_core_news_md', disable=['ner', 'parser'])
+bertnlp_model = None
+bert_tokenizer = None
 nlp_model = None
+spacy.prefer_gpu()
 
 
 class CleanText():
@@ -38,7 +38,7 @@ class CleanText():
             verbose: bool
             If True prints when the input is not a string.
         """
-        METHOD_NAME="init"
+        METHOD_NAME = "init"
         if type(input_txt) == str:
             self.input_txt = input_txt
         else:
@@ -46,7 +46,8 @@ class CleanText():
             print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
             self.input_txt = ''
 
-    def process_text(self, rts=False, mentions=False, hashtags=False, links=False, spec_chars=False):
+    def process_text(
+            self, rts=False, mentions=False, hashtags=False, links=False, spec_chars=False):
         """
         This functions cleans the input text.
 
@@ -84,19 +85,21 @@ class CleanText():
             mention_pattern = re.compile(r'\@[a-zA-Z0-9\-\_]+\b')
             input_txt = re.sub(mention_pattern, '', input_txt)
         else:
-            input_txt = input_txt.replace('@', 'xxatsignxx') #procect '@' signs of being removed in spec_chars
+            input_txt = input_txt.replace(
+                '@', 'xxatsignxx')    #procect '@' signs of being removed in spec_chars
         if hashtags:
             hashtag_pattern = re.compile(r'\#[a-zA-Z0-9\-\_]+\b')
             input_txt = re.sub(hashtag_pattern, '', input_txt)
         else:
-            input_txt = input_txt.replace('#', 'xxhashtagsignxx') #procect '#' signs to being removed in spec_chars
+            input_txt = input_txt.replace(
+                '#', 'xxhashtagsignxx')    #procect '#' signs to being removed in spec_chars
         if links:
             link_pattern = re.compile(r'\bhttps:.+\b')
             input_txt = re.sub(link_pattern, '', input_txt)
             link_pattern = re.compile(r'\bhttp:.+\b')
             input_txt = re.sub(link_pattern, '', input_txt)
         if spec_chars:
-            input_txt = re.sub(r'[^a-zA-Z\u00C0-\u00FF ]', ' ',input_txt)
+            input_txt = re.sub(r'[^a-zA-Z\u00C0-\u00FF ]', ' ', input_txt)
         input_txt = input_txt.split()
         output_txt = ' '.join(input_txt)
         output_txt = output_txt.replace('xxatsignxx', '@')
@@ -133,7 +136,7 @@ class Features():
         dict: keys -> tokens, lemmas and part of speech tags.
         i
         """
-        METHOD_NAME="pos_tags"
+        METHOD_NAME = "pos_tags"
         self.input_txt = input_txt
         if type(input_txt) != str:
             print('ERROR: Input is not a string.')
@@ -156,26 +159,19 @@ class Features():
                     lemmas.append(feat[1])
                     pos_tags.append(feat[2])
 
-            out_dict = {
-                'words': words,
-                'lemmas': lemmas,
-                'pos_tags': pos_tags
-            }
+            out_dict = {'words': words, 'lemmas': lemmas, 'pos_tags': pos_tags}
         except Exception as e:
             print(e)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
             print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
-            out_dict = {
-                'words': [],
-                'lemmas': [],
-                'pos_tags': []
-            }
+            out_dict = {'words': [], 'lemmas': [], 'pos_tags': []}
 
         return out_dict
 
 
 class Polarity(object):
+
     def __init__(self):
         self.polscore = [-1.0, -0.5, 0, 0.5, 1.0]
         self.device = "cuda" if torch.cuda.is_available() else "cpu"
@@ -189,15 +185,15 @@ class Polarity(object):
 
     def tokenize_texts(self, text_list, max_length=128):
 
-
-        encoded_dict = tokenizer.batch_encode_plus(text_list,
-                        add_special_tokens = True,     # Add '[CLS]' and '[SEP]'
-                        truncation=True,
-                        max_length = max_length,              # THIS SHOULD BE CHANGED IS JUST EXAMPLE!!!!
-                        pad_to_max_length = True,      # Pad & truncate all sentences to max_length
-                        return_attention_mask = True,  # Construct attn. masks.
-                        return_tensors = 'pt',         # Return pytorch tensors.
-                   )
+        encoded_dict = tokenizer.batch_encode_plus(
+            text_list,
+            add_special_tokens=True,    # Add '[CLS]' and '[SEP]'
+            truncation=True,
+            max_length=max_length,    # THIS SHOULD BE CHANGED IS JUST EXAMPLE!!!!
+            pad_to_max_length=True,    # Pad & truncate all sentences to max_length
+            return_attention_mask=True,    # Construct attn. masks.
+            return_tensors='pt',    # Return pytorch tensors.
+        )
 
         # Convert the input_ids lists into tensors (expand in first dim as we suppose is the batch size).
         input_ids_b = encoded_dict['input_ids']
@@ -208,38 +204,42 @@ class Polarity(object):
     def forward_model(self, data):
 
         (input_ids_b, attention_masks_b) = data
-        (out,) = model(input_ids_b.to(self.device),
-                           token_type_ids=None,
-                           attention_mask=attention_masks_b.to(self.device),
-                           labels=None)
+        (out,) = model(
+            input_ids_b.to(self.device),
+            token_type_ids=None,
+            attention_mask=attention_masks_b.to(self.device),
+            labels=None)
 
-        sentiment = list( out.argmax(1).numpy() )
+        sentiment = list(out.argmax(1).numpy())
 
         return sentiment
 
     def batch_forward(self, text_list, batch_size, max_length):
 
         num_texts = len(df_text)
-        batch_idx = slice(0,num_texts, batch_size)
+        batch_idx = slice(0, num_texts, batch_size)
 
         polarity = []
-        for i in range(num_texts//batch_size):
-            batch_idx = slice( batch_size*i, batch_size*(i+1), 1)
-            (input_ids_b, attention_masks_b) = self.tokenize_texts( text_list[batch_idx], max_length=max_length)
+        for i in range(num_texts // batch_size):
+            batch_idx = slice(batch_size * i, batch_size * (i + 1), 1)
+            (input_ids_b, attention_masks_b) = self.tokenize_texts(
+                text_list[batch_idx], max_length=max_length)
             sentiment_list = forward_model((input_ids_b, attention_masks_b))
 
-            polarity.extend( sentiment_list )
+            polarity.extend(sentiment_list)
 
-        if num_texts%batch_size:
-            batch_idx = slice(batch_size*(num_texts//batch_size),num_texts,1)
-            (input_ids_b, attention_masks_b) = self.tokenize_texts( text_list[batch_idx], max_length=max_length)
+        if num_texts % batch_size:
+            batch_idx = slice(batch_size * (num_texts // batch_size), num_texts, 1)
+            (input_ids_b, attention_masks_b) = self.tokenize_texts(
+                text_list[batch_idx], max_length=max_length)
             sentiment_list = self.forward_model((input_ids_b, attention_masks_b))
 
-            polarity.extend( sentiment_list )
+            polarity.extend(sentiment_list)
 
         return polarity
 
-    def batch_polarity(self, df_text, text_column_name ='processed_text', batch_size=2, max_length=128):
+    def batch_polarity(
+            self, df_text, text_column_name='processed_text', batch_size=2, max_length=128):
         """
         This function returns the polarity of an input texts procesed by batches.
 
@@ -269,9 +269,10 @@ class Polarity(object):
 
         if isinstance(df_text, pd.DataFrame):
             try:
-                df_text['polarity'] = self.batch_forward( list(df_text[text_column_name]), batch_size=batch_size, max_length=max_length)
-                dict_polscore = {idx: score for idx, score in enumerate(self.polscore) }
-                df_text['polarity'] = df_text['polarity'].map( dict_polscore )
+                df_text['polarity'] = self.batch_forward(
+                    list(df_text[text_column_name]), batch_size=batch_size, max_length=max_length)
+                dict_polscore = {idx: score for idx, score in enumerate(self.polscore)}
+                df_text['polarity'] = df_text['polarity'].map(dict_polscore)
 
             except Exception as e:
                 print(e)
@@ -283,17 +284,18 @@ class Polarity(object):
 
         elif isinstance(df_text, str):
             print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
-            print(f'Must recieve a list of string of pandas DataFrame with strings. returning -100 ...')
+            print(
+                f'Must recieve a list of string of pandas DataFrame with strings. returning -100 ...'
+            )
             return -100
 
         else:
             print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
             print('Calling polarity method for a non-string variable. returning -100 ...')
-            polarity=-100
+            polarity = -100
             return polarity
 
-    def polarity(self, df_text, text_column_name ='processed_text'):
-
+    def polarity(self, df_text, text_column_name='processed_text'):
         """
         This function returns the polarity of an input text(s).
 
@@ -314,59 +316,65 @@ class Polarity(object):
         METHOD_NAME = 'polarity'
 
         if isinstance(df_text, list) and all(isinstance(text, str) for text in df_text):
-            df_text=pd.DataFrame(columns=['message'], data=df_text)
-            df_text['processed_text'] = df_text['message'].apply(lambda msg: CleanText(msg).process_text(mentions=True, hashtags=True, links=True, spec_chars=True))
+            df_text = pd.DataFrame(columns=['message'], data=df_text)
+            df_text['processed_text'] = df_text['message'].apply(
+                lambda msg: CleanText(msg).process_text(
+                    mentions=True, hashtags=True, links=True, spec_chars=True))
             df_text = df_text.dropna(subset=['processed_text'])
-            df_text = df_text.drop(df_text[df_text['processed_text']==""].index)
+            df_text = df_text.drop(df_text[df_text['processed_text'] == ""].index)
 
         if isinstance(df_text, pd.DataFrame):
 
             try:
-                df_text['tokenized_data']=df_text[text_column_name].apply(lambda msg: self.tokenizer.encode(msg))
-                df_text['len_tokenized_data']=df_text.tokenized_data.apply(lambda l: len(l))
-                df_text=df_text[df_text.tokenized_data.str.len()<511]
-                df_text['tokenized_data']=df_text.tokenized_data.apply(lambda l: torch.tensor([l]))
-                df_text['polarity']=df_text.tokenized_data.apply(lambda tkd: self.polscore[self.softmax(self.model(tkd.to(self.device) )[0]).argmax()])
+                df_text['tokenized_data'] = df_text[text_column_name].apply(
+                    lambda msg: self.tokenizer.encode(msg))
+                df_text['len_tokenized_data'] = df_text.tokenized_data.apply(lambda l: len(l))
+                df_text = df_text[df_text.tokenized_data.str.len() < 511]
+                df_text['tokenized_data'] = df_text.tokenized_data.apply(
+                    lambda l: torch.tensor([l]))
+                df_text['polarity'] = df_text.tokenized_data.apply(
+                    lambda tkd: self.polscore[self.softmax(self.model(tkd.to(self.device))[0]).
+                                              argmax()])
             except Exception as e:
                 print(e)
                 error_1 = sys.exc_info()[0]
                 print(ERR_SYS + str(error_1))
                 print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
-                df_text['polarity']=""
+                df_text['polarity'] = ""
             return df_text
 
         elif isinstance(df_text, str):
             try:
-                text_tokens = self.tokenizer.encode(df_text,return_tensors="pt")
+                text_tokens = self.tokenizer.encode(df_text, return_tensors="pt")
 
                 #if the text is too long the model does not work
-                if(len(text_tokens[0])>512):
+                if (len(text_tokens[0]) > 512):
                     print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
                     print('text too long for polarity model. returning -100 ...')
                     polarity = -100
                     return polarity
                 else:
-                    output      = self.softmax(self.model(text_tokens)[0])
-                    polarity    = self.polscore[output.argmax()]
+                    output = self.softmax(self.model(text_tokens)[0])
+                    polarity = self.polscore[output.argmax()]
 
             except Exception as e:
                 print(e)
                 error_1 = sys.exc_info()[0]
                 print(ERR_SYS + str(error_1))
                 print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
-                polarity=-100
+                polarity = -100
             return polarity
 
         else:
             print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
             print('Calling polarity method for a non-string variable. returning -100 ...')
-            polarity=-100
+            polarity = -100
             return polarity
 
 
 class STTM(object):
 
-    def __init__(self, df_data, text_column_name ='tokenized_text'):
+    def __init__(self, df_data, text_column_name='tokenized_text'):
         """
         This function stores the input DataFrame.
 
@@ -406,11 +414,11 @@ class STTM(object):
             DataFrame with the 'sttm_group' column
 
         """
-        METHOD_NAME='sttm_model'
+        METHOD_NAME = 'sttm_model'
         try:
 
             # Input format for the STTM model : list of strings (list of tokens)
-            docs = self.df_data[self.text_column_name].tolist() #tokenized_data.tokens.tolist()
+            docs = self.df_data[self.text_column_name].tolist()    #tokenized_data.tokens.tolist()
             vocab = set(x for doc in docs for x in doc)
             n_terms = len(vocab)
             n_docs = len(docs)
@@ -435,11 +443,11 @@ class STTM(object):
             print(f'Class: {self.__str__()}\nMethod: {METHOD_NAME}')
             self.df_data['sttm_group'] = ""
 
-
         return self.df_data
 
 
 class MovieGroupProcess:
+
     def __init__(self, K=8, alpha=0.1, beta=0.1, n_iters=30):
         '''
         A MovieGroupProcess is a conceptual model introduced by Yin and Wang 2014 to
@@ -479,7 +487,9 @@ class MovieGroupProcess:
         self.cluster_word_distribution = [{} for i in range(K)]
 
     @staticmethod
-    def from_data(K, alpha, beta, D, vocab_size, cluster_doc_count, cluster_word_count, cluster_word_distribution):
+    def from_data(
+            K, alpha, beta, D, vocab_size, cluster_doc_count, cluster_word_count,
+            cluster_word_distribution):
         '''
         Reconstitute a MovieGroupProcess from previously fit data
         :param K:
@@ -581,9 +591,10 @@ class MovieGroupProcess:
                     n_z_w[z_new][word] += 1
 
             cluster_count_new = sum([1 for v in m_z if v > 0])
-            print("In stage %d: transferred %d clusters with %d clusters populated" % (
-            _iter, total_transfers, cluster_count_new))
-            if total_transfers == 0 and cluster_count_new == cluster_count and _iter>25:
+            print(
+                "In stage %d: transferred %d clusters with %d clusters populated" %
+                (_iter, total_transfers, cluster_count_new))
+            if total_transfers == 0 and cluster_count_new == cluster_count and _iter > 25:
                 print("Converged.  Breaking out.")
                 break
             cluster_count = cluster_count_new
@@ -621,14 +632,14 @@ class MovieGroupProcess:
             lD2 = 0
             for word in doc:
                 lN2 += log(n_z_w[label].get(word, 0) + beta)
-            for j in range(1, doc_size +1):
+            for j in range(1, doc_size + 1):
                 lD2 += log(n_z[label] + V * beta + j - 1)
             p[label] = exp(lN1 - lD1 + lN2 - lD2)
 
         # normalize the probability vector
         pnorm = sum(p)
-        pnorm = pnorm if pnorm>0 else 1
-        return [pp/pnorm for pp in p]
+        pnorm = pnorm if pnorm > 0 else 1
+        return [pp / pnorm for pp in p]
 
     def choose_best_label(self, doc):
         '''
@@ -637,5 +648,4 @@ class MovieGroupProcess:
         :return:
         '''
         p = self.score(doc)
-        return argmax(p),max(p)
-
+        return argmax(p), max(p)
